#################################################################################
#
#  Licensed Materials - Property of IBM
#  Restricted Material of IBM
#  IBM Rational Test RealTime
#  (c) Copyright IBM Corp. 2003-2006 All Rights Reserved.
#
#  US Governement Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#################################################################################

##########################################################################
#                                                                        # #
# Rational Test RealTime                                                 #   #
#                                                                        #######
#                     -*-  Import Makefile -*-                                 #
#                                                                              #
#                                                                              #
#  Script for importing a Makefile.                                            #
#                                                                              #
#  usage:                                                                      #
#       ImportMakefile.pl <environment file>                                   # 
#                                                                              #
# Required global variables:                                                   #
#   $BINDIR		 : binary directory required for the PerlTranslate     #
#   $SCRIPTDIR           : directory of the scripts                            #
#   $IMPORTFILE          : key of the Makefile to be imported                  #
#   $PROJECTNAME         : name for the created project                        #
#   $TDPNAME
#   $TARGETDIR
#   $INIFILE
#   $OBJEXT
#   $EXEEXT
#   $SRCEXT
#   $CPPFLAGS
#   $CFLAGS
#   $TCFLAGS
#   $LDFLAGS
#   $LIBRARIES
#   $TDP_LANGUAGE
#   $INTDIR
#   $OUTDIR
#   $INCLUDE_DIR_LIST
#   $LIBRARY_DIR_LIST
#   $JAVA_BOOTCLASSPATH
#   $J2ME_RESTRICTION
#                                                                              #
#                                                                              #
################################################################################
#$Id: ImportMakefile.pl,v 1.29 2006/02/01 15:09:26 build Exp $
################################################################################

use FileHandle ;
STDOUT->autoflush(1);

# This script depends on the followings
require $ARGV[0]; #environment and global variables.

# Miscellaneous functions
require $SCRIPTDIR . "Fcts.pl";

$DEBUG=0;

################################################################################
# Here is the beginning
################################################################################
&EnterInScript;

#----------------------------------------------------------------------------
## 
print &PerlTranslate("ImportMakefile.pl", "Importing files from the Makefile: \"%1\"...\n", "%1 is the Makefile name", $IMPORTFILE);

open (MAKFILE,"$IMPORTFILE") || die &PerlTranslate("ImportMakefile.pl", "Cannot open %1", "%1 is the Makefile name", $IMPORTFILE);

my ($dir,$n,$ext1) = SplitFileName($IMPORTFILE);
$MKFDIR = $dir;

$projectFileName = $PROJECTNAME . ".rtp";
$infoFileName = $PROJECTNAME . ".inf";

ClearLogFile( $projectFileName );
ClearLogFile( $infoFileName );
open (IMPORTMVS_RTP,">>$projectFileName") || die &PerlTranslate("ImportMakefile.pl", "Error: Cannot write in %1\n", "%1 is the file that cannot be written", $projectFileName) ;
open (IMPORTMVS_INF,">>$infoFileName") || die &PerlTranslate("ImportMakefile.pl", "Error: Cannot write in %1\n", "%1 is the file that cannot be written", $infoFileName);

################################################################################
# Header of RTP file
################################################################################
printf IMPORTMVS_RTP "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";
printf IMPORTMVS_RTP "<!DOCTYPE project SYSTEM \n\"$ENV{'ATTOLHOME'}"."/lib/project.dtd\" >\n";
printf IMPORTMVS_RTP "<project>\n";
printf IMPORTMVS_RTP "  <group>\n";
printf IMPORTMVS_RTP "    <node>\n";
printf IMPORTMVS_RTP "      <data>\n";
printf IMPORTMVS_RTP "        <name>$PROJECTNAME</name>\n";
printf IMPORTMVS_RTP "        <renameable>false</renameable>\n";
printf IMPORTMVS_RTP "        <deletable>false</deletable>\n";
printf IMPORTMVS_RTP "        <open>true</open>\n";
printf IMPORTMVS_RTP "      </data>\n";
printf IMPORTMVS_RTP "      <current_configuration>$TDPNAME</current_configuration>\n";
printf IMPORTMVS_RTP "      <checked>false</checked>\n";
printf IMPORTMVS_RTP "      <background>false</background>\n";
printf IMPORTMVS_RTP "      <configuration_list>\n";
printf IMPORTMVS_RTP "        <configuration>\n";
printf IMPORTMVS_RTP "          <data>\n";
printf IMPORTMVS_RTP "            <name>$TDPNAME</name>\n";
printf IMPORTMVS_RTP "            <renameable>true</renameable>\n";
printf IMPORTMVS_RTP "            <deletable>true</deletable>\n";
printf IMPORTMVS_RTP "            <open>false</open>\n";
printf IMPORTMVS_RTP "          </data>\n";
printf IMPORTMVS_RTP "        <executionFlag>7743</executionFlag>\n";
printf IMPORTMVS_RTP "        </configuration>\n";
printf IMPORTMVS_RTP "      </configuration_list>\n";
printf IMPORTMVS_RTP "    </node>\n";

printf IMPORTMVS_RTP "    <group_child>\n";
printf IMPORTMVS_RTP "      <application>\n";
printf IMPORTMVS_RTP "        <test>\n";
printf IMPORTMVS_RTP "          <node>\n";
printf IMPORTMVS_RTP "            <data>\n";
printf IMPORTMVS_RTP "              <name>$PROJECTNAME</name>\n";
printf IMPORTMVS_RTP "              <renameable>true</renameable>\n";
printf IMPORTMVS_RTP "              <deletable>true</deletable>\n";
printf IMPORTMVS_RTP "              <open>true</open>\n";
printf IMPORTMVS_RTP "            </data>\n";
printf IMPORTMVS_RTP "            <current_configuration>$TDPNAME</current_configuration>\n";
printf IMPORTMVS_RTP "            <checked>false</checked>\n";
printf IMPORTMVS_RTP "            <background>false</background>\n";
printf IMPORTMVS_RTP "            <perlscript_after_child>Application.pl</perlscript_after_child>\n";
printf IMPORTMVS_RTP "            <configuration_list>\n";
printf IMPORTMVS_RTP "              <configuration>\n";
printf IMPORTMVS_RTP "                <data>\n";
printf IMPORTMVS_RTP "                  <name>$TDPNAME</name>\n";
printf IMPORTMVS_RTP "                  <renameable>true</renameable>\n";
printf IMPORTMVS_RTP "                  <deletable>true</deletable>\n";
printf IMPORTMVS_RTP "                  <open>false</open>\n";
printf IMPORTMVS_RTP "                </data>\n";
printf IMPORTMVS_RTP "              </configuration>\n";
printf IMPORTMVS_RTP "            </configuration_list>\n";
printf IMPORTMVS_RTP "          </node>\n";
printf IMPORTMVS_RTP "          <test_child>\n";


################################################################################
# Header of INF file
################################################################################
printf IMPORTMVS_INF "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";
printf IMPORTMVS_INF "<!DOCTYPE project SYSTEM \n\"$ENV{'ATTOLHOME'}"."/lib/project.dtd\" >\n";
printf IMPORTMVS_INF "<objects>\n";
printf IMPORTMVS_INF "  <folder>\n";
printf IMPORTMVS_INF "    <data>\n";
printf IMPORTMVS_INF "      <name>$PROJECTNAME</name>\n";
printf IMPORTMVS_INF "      <renameable>false</renameable>\n";
printf IMPORTMVS_INF "      <deletable>true</deletable>\n";
printf IMPORTMVS_INF "      <open>true</open>\n";
printf IMPORTMVS_INF "    </data>\n";
printf IMPORTMVS_INF "    <filters></filters>\n";
printf IMPORTMVS_INF "    <folder_child>\n";


sub Subsitute
{
    my $Value0=shift;
    while ($Value0=~/\$\(\w+\)/) # $(<mot>)
    {
	$DEBUG && print "Have to substitute a value \"$Value0\"\n";
	my $temp=$Value0;
	$temp=~s/.*\$\((\w+?)\).*/$1/;
	my $word = $1;
	$DEBUG && print "The word to substitute is \"$word\"\n";
	if (exists($ENV{$word}))
	{
	    $DEBUG && print "Substituting \"",$ENV{$word},"\" for \"$word\"\n";
	    $Value0=~s/\$\(\Q$word\E\)/$ENV{$word}/; 
	    $DEBUG && print "Line is now $Value0\n";
	}
	else 
	{
	    if (exists($Macros{$word}))
	    {
		$DEBUG && print "Substituting macro \"",$Macros{$word},"\" for \"$word\"\n";
		$value = $Macros{$word};
		$Value0=~s/\$\(\Q$word\E\)/$value/;
		$DEBUG && print "Line is now $Value0\n";
	    }
	    else 
	    {
		print &PerlTranslate("ImportMakefile.pl", "Warning: cannot find this variable: \"%1\"\n", "%1 is the name of the variable", $word);
		$Value0=~s/\$\(\Q$word\E\)//;
		  #exit(1);
	    }
	}
    }
    return $Value0;
}

sub MyFormat
{
    my $Value0 = $_;
    my ($dir,$name,$ext) = SplitFileName($Value0);

    # suppression des 'parasites' en debut ou fin de chaine... 
    $Value0 =~s/[:|+|=|\\]$//;
    $Value0 =~s/^[:|+|=]//;
    # absolute path...
    if ( !$dir || $dir=~/^\.[a-zA-Z0-9_]/ || $dir=~/^\.\.\\/ || $dir=~/^\.\.\// ){
	$Value0 = "$MKFDIR" . "$Value0";
    }
    if ( $dir=~/^\.[\/|\\]/ ) 
    {
	$Value0=~s/^\.[\/|\\]//;
	$Value0 = "$MKFDIR" . "$Value0";
    }
    # pb des "/" et "\"
    $Value0 =~ s/[\\|\/]/$PATH_SEPARATOR/g;
    # suppression des ".." dans le path
    my $Count = 0;
    while ($Value0 =~ /\.\./) {
	$Value0 =~ s/[\\\/][^\.\\\/]*[\\\/]\.\.//g;
	$Count++;
	last if ($Count > 50); # Make sure we never loop forever
    }
    return ($Value0);
}

my %LaListe;
my %Includes;

while(<MAKFILE>)
{
    chomp;
    next if(/^\s*$/);
    next if(/^\s*\#/);
    $DEBUG && print "Processing: ",$_,"\n";
    if(/=/)
    {
	my ($Name,$Value)=split(/=/);
	$Name=~s/\s//g;
	$DEBUG && print "Found \"$Name\" and value \"$Value\"\n";
	$Value=Subsitute $Value; #pour cas d'1 macro dependante d'autre(s) 
	$DEBUG && print "Defining \"$Name\" with value \"$Value\"\n";
	$Macros{$Name}= $Value;
    }
    else
    {
	$Value=$_;	
    }

    $Value=Subsitute $Value; #retourne le chemin apres execution des MACROS
    $DEBUG && print "Substitute: ",$Value,"\n";

    # Extract all the include directories if there are any.
    while ($Value =~ m,\s+[/-]I([^\s]+)\s+,g) {
      $Includes{$1}++;
    }

    my @sources=split /\s+|:(?=[^\\])/,$Value;

    foreach (@sources)
    {
        $Value=$_;
	next if(!$Value);
	$DEBUG && print "Process Source: $Value\n";
	if ($Value=~/[-a-zA-Z0-9_]\.cpp/)
	{
	    $Value=~s/.*[^-\.a-zA-Z0-9\\\/_:]([-\.a-zA-Z0-9\\\/_:]+\.cpp).*/$1/;
	    $DEBUG && print "Adding \"$Value\" to the list of files\n";
	    $LaListe{$Value}=1;
	}
	elsif ($Value=~/[-a-zA-Z0-9_]\.c/)
	{
	    $Value=~s/.*[^-\.a-zA-Z0-9\\\/_:]([-\.a-zA-Z0-9\\\/_:]+\.c).*/$1/;
	    $DEBUG && print "Adding \"$Value\" to the list of files\n";
	    $LaListe{$Value}=1;
	}
	elsif ($Value=~/[-a-zA-Z0-9_]\.C/)
	{
	    $Value=~s/.*[^-\.a-zA-Z0-9\\\/_:]([-\.a-zA-Z0-9\\\/_:]+\.C).*/$1/;
	    $DEBUG && print "Adding \"$Value\" to the list of files\n";
	    $LaListe{$Value}=1;
	}
	elsif ($Value=~/[-a-zA-Z0-9_]\.ada/)
	{
	    $Value=~s/.*[^-\.a-zA-Z0-9\\\/_:]([-\.a-zA-Z0-9\\\/_:]+\.ada).*/$1/;
	    $DEBUG && print "Adding \"$Value\" to the list of files\n";
	    $LaListe{$Value}=1;
	}
	elsif ($Value=~/[-a-zA-Z0-9_]\.ads/)
	{
	    $Value=~s/.*[^-\.a-zA-Z0-9\\\/_:]([-\.a-zA-Z0-9\\\/_:]+\.ads).*/$1/;
	    $DEBUG && print "Adding \"$Value\" to the list of files\n";
	    $LaListe{$Value}=1;
	}
	elsif ($Value=~/[-a-zA-Z0-9_]\.adb/)
	{
	    $Value=~s/.*[^-\.a-zA-Z0-9\\\/_:]([-\.a-zA-Z0-9\\\/_:]+\.adb).*/$1/;
	    $DEBUG && print "Adding \"$Value\" to the list of files\n";
	    $LaListe{$Value}=1;
	}
	elsif ($Value=~/[-a-zA-Z0-9_]\.java/)
	{
	    $Value=~s/.*[^-\.a-zA-Z0-9\\\/_:]([-\.a-zA-Z0-9\\\/_:]+\.java).*/$1/;
	    $DEBUG && print "Adding \"$Value\" to the list of files\n";
	    $LaListe{$Value}=1;
	}
    }
}

#Recover the includes that have been found:
$INCLUDE_DIR_LIST = join (',', keys %Includes);

###############################################################################
#  Suite du fichier INF
###############################################################################
printf IMPORTMVS_INF "      <folder>\n";
printf IMPORTMVS_INF "        <data>\n";
printf IMPORTMVS_INF "          <name>Scripts</name>\n";
printf IMPORTMVS_INF "          <renameable>true</renameable>\n";
printf IMPORTMVS_INF "          <deletable>true</deletable>\n";
printf IMPORTMVS_INF "          <open>true</open>\n";
printf IMPORTMVS_INF "        </data>\n";
printf IMPORTMVS_INF "        <filters>*.ptu;*.pts;*.otd;*.otc;*.dcl;*.stb</filters>\n";
printf IMPORTMVS_INF "        <folder_child>\n";

foreach (sort keys %LaListe) {
    $DEBUG && print "Treating the file \"$_\"\n";
    $DEBUG && print "Value before MyFormat = $_\n";
    $Value = MyFormat $_;

    $DEBUG && print "Value after MyFormat = $Value\n";
    #if ( stat($Value) ) {
	my ($dir1,$name1,$ext1) = SplitFileName($Value);
	#if($ext1 =~ "cpp" or $ext1 =~ "rc") {
	if($ext1 =~ "h" or $ext1 =~ "hxx" or $ext1 =~ "c" or $ext1 =~ "cpp" or
	   $ext1 =~ "cxx" or $ext1 =~ "cc" or $ext1 =~ "java" or $ext1 =~ "ada" or
	   $ext1 =~ "adb" or $ext1 =~ "ads" or $ext1 =~ "spv" or $ext1 =~ "mat" or
	   $ext1 =~ "mdl" or $ext1 =~ "rc")
	{
	    $source = $Value;
	    printf IMPORTMVS_RTP "            <source>\n";
	    printf IMPORTMVS_RTP "              <nodefile_ref>\n";
	    printf IMPORTMVS_RTP "                <node>\n";
	    printf IMPORTMVS_RTP "                  <data>\n";
	    printf IMPORTMVS_RTP "                    <name>$name1.$ext1</name>\n";
	    printf IMPORTMVS_RTP "                    <renameable>false</renameable>\n";
	    printf IMPORTMVS_RTP "                    <deletable>true</deletable>\n";
	    printf IMPORTMVS_RTP "                    <open>false</open>\n";
	    printf IMPORTMVS_RTP "                  </data>\n";
	    printf IMPORTMVS_RTP "                  <current_configuration>$TDPNAME</current_configuration>\n";
	    printf IMPORTMVS_RTP "                  <checked>false</checked>\n";
	    printf IMPORTMVS_RTP "                  <background>false</background>\n";
	    printf IMPORTMVS_RTP "                  <perlscript_after_child>Source.pl</perlscript_after_child>\n";
	    printf IMPORTMVS_RTP "                  <configuration_list>\n";
	    printf IMPORTMVS_RTP "                    <configuration>\n";
	    printf IMPORTMVS_RTP "                      <data>\n";
	    printf IMPORTMVS_RTP "                        <name>$TDPNAME</name>\n";
	    printf IMPORTMVS_RTP "                        <renameable>true</renameable>\n";
	    printf IMPORTMVS_RTP "                        <deletable>true</deletable>\n";
	    printf IMPORTMVS_RTP "                        <open>true</open>\n";
	    printf IMPORTMVS_RTP "                      </data>\n";
	    printf IMPORTMVS_RTP "                    </configuration>\n";
	    printf IMPORTMVS_RTP "                  </configuration_list>\n";
	    printf IMPORTMVS_RTP "                </node>\n";
	    printf IMPORTMVS_RTP "                <filepath>$source</filepath>\n";
	    printf IMPORTMVS_RTP "              </nodefile_ref>\n";
	    printf IMPORTMVS_RTP "              <integrated>false</integrated>\n";
	    printf IMPORTMVS_RTP "              <source_child>\n";
	    printf IMPORTMVS_RTP "              </source_child>\n";
	    printf IMPORTMVS_RTP "            </source>\n";
	}
	if($ext1 =~ "ptu" or $ext1 =~ "pts" or $ext1 =~ "otd" or $ext1 =~ "otc"
	   or $ext1 =~ "dcl" or $ext1 =~ "stb") {
	    printf IMPORTMVS_INF "          <file>\n";
	    printf IMPORTMVS_INF "            <tested_tag>\n";
	    printf IMPORTMVS_INF "              <tag>\n";
	    printf IMPORTMVS_INF "                <data>\n";
	    printf IMPORTMVS_INF "                  <name>$name1.$ext1</name>\n";
	    printf IMPORTMVS_INF "                  <renameable>true</renameable>\n";
	    printf IMPORTMVS_INF "                  <deletable>true</deletable>\n";
	    printf IMPORTMVS_INF "                  <open>true</open>\n";
	    printf IMPORTMVS_INF "                </data>\n";
	    printf IMPORTMVS_INF "                <filepath>$MKFDIR$name1.$ext1</filepath>\n";
	    printf IMPORTMVS_INF "                <line>1</line>\n";
	    printf IMPORTMVS_INF "                <qualifier>0</qualifier>\n";
	    printf IMPORTMVS_INF "                <tag_child>\n";
	    printf IMPORTMVS_INF "                </tag_child>\n";
	    printf IMPORTMVS_INF "              </tag>\n";
	    printf IMPORTMVS_INF "            </tested_tag>\n";
	    printf IMPORTMVS_INF "            <filepath>$dir1$name1.$ext1</filepath>\n";
	    printf IMPORTMVS_INF "            <last_modification></last_modification>\n";
	    printf IMPORTMVS_INF "          </file>\n";
	}
    #}
}

printf IMPORTMVS_INF "        </folder_child>\n";
printf IMPORTMVS_INF "      </folder>\n";

printf IMPORTMVS_INF "      <folder>\n";
printf IMPORTMVS_INF "        <data>\n";
printf IMPORTMVS_INF "          <name>Sources</name>\n";
printf IMPORTMVS_INF "          <renameable>true</renameable>\n";
printf IMPORTMVS_INF "          <deletable>true</deletable>\n";
printf IMPORTMVS_INF "          <open>true</open>\n";
printf IMPORTMVS_INF "        </data>\n";
printf IMPORTMVS_INF "        <filters>*.h;*.hxx;*.c;*.cpp;*.cxx;*.cc;*.java;*.ada;*.adb;*.ads;*.spv;*.mat;*.mdl;*.rc;*</filters>\n";
printf IMPORTMVS_INF "        <folder_child>\n";

foreach (sort keys %LaListe) {
    $Value = MyFormat $_;
    $DEBUG && print "File for .inf file = $Value\n";
	my ($dir1,$name1,$ext1) = SplitFileName($Value);
	$DEBUG && print "split dir = $dir1 , name = $name1 , ext = $ext1\n";
	#if($ext1 =~ "h" or $ext1 =~ "hxx" or $ext1 =~ "c" or $ext1 =~ "cpp" or
	#   $ext1 =~ "cxx" or $ext1 =~ "cc" or $ext1 =~ "java" or $ext1 =~ "ada" or
	#   $ext1 =~ "adb" or $ext1 =~ "ads" or $ext1 =~ "spv" or $ext1 =~ "mat" or
	#   $ext1 =~ "mdl" or $ext1 =~ "rc" or $ext1 =~ "" )
	#   {
	       printf IMPORTMVS_INF "          <file>\n";
	       printf IMPORTMVS_INF "            <tested_tag>\n";
	       printf IMPORTMVS_INF "              <tag>\n";
	       printf IMPORTMVS_INF "                <data>\n";
	       printf IMPORTMVS_INF "                  <name>$name1.$ext1</name>\n";
	       printf IMPORTMVS_INF "                  <renameable>true</renameable>\n";
	       printf IMPORTMVS_INF "                  <deletable>true</deletable>\n";
	       printf IMPORTMVS_INF "                  <open>true</open>\n";
	       printf IMPORTMVS_INF "                </data>\n";
	       printf IMPORTMVS_INF "                <filepath>$MKFDIR$name1.$ext1</filepath>\n";
	       printf IMPORTMVS_INF "                <line>1</line>\n";
	       printf IMPORTMVS_INF "                <qualifier>0</qualifier>\n";
	       printf IMPORTMVS_INF "                <tag_child>\n";
	       printf IMPORTMVS_INF "                </tag_child>\n";
	       printf IMPORTMVS_INF "              </tag>\n";
	       printf IMPORTMVS_INF "            </tested_tag>\n";
	       printf IMPORTMVS_INF "            <filepath>$dir1$name1.$ext1</filepath>\n";
	       printf IMPORTMVS_INF "            <last_modification></last_modification>\n";
	       printf IMPORTMVS_INF "          </file>\n";
	   #}
    #}
}

printf IMPORTMVS_INF "        </folder_child>\n";
printf IMPORTMVS_INF "      </folder>\n";

printf IMPORTMVS_INF "      <folder>\n";
printf IMPORTMVS_INF "        <data>\n";
printf IMPORTMVS_INF "          <name>Dependencies</name>\n";
printf IMPORTMVS_INF "          <renameable>true</renameable>\n";
printf IMPORTMVS_INF "          <deletable>true</deletable>\n";
printf IMPORTMVS_INF "          <open>true</open>\n";
printf IMPORTMVS_INF "        </data>\n";
printf IMPORTMVS_INF "        <filters></filters>\n";
printf IMPORTMVS_INF "        <folder_child>\n";
printf IMPORTMVS_INF "        </folder_child>\n";
printf IMPORTMVS_INF "      </folder>\n";


###############################################################################
#  Suite du fichier RTP
###############################################################################
printf IMPORTMVS_RTP "          </test_child>\n";
printf IMPORTMVS_RTP "        </test>\n";
printf IMPORTMVS_RTP "      </application>\n";
printf IMPORTMVS_RTP "    </group_child>\n";
printf IMPORTMVS_RTP "  </group>\n";

printf IMPORTMVS_RTP "  <object_file>$PROJECTNAME.inf</object_file>\n";
printf IMPORTMVS_RTP "  <root_configuration_list>\n";
printf IMPORTMVS_RTP "    <configuration>\n";
printf IMPORTMVS_RTP "      <data>\n";
printf IMPORTMVS_RTP "        <name>$TDPNAME</name>\n";
printf IMPORTMVS_RTP "        <renameable>true</renameable>\n";
printf IMPORTMVS_RTP "        <deletable>true</deletable>\n";
printf IMPORTMVS_RTP "        <open>true</open>\n";
printf IMPORTMVS_RTP "      </data>\n";
printf IMPORTMVS_RTP "      <computerName>local host</computerName>\n";
printf IMPORTMVS_RTP "      <computerAddress>127.0.0.1</computerAddress>\n";
printf IMPORTMVS_RTP "      <computerPort>10000</computerPort>\n";
printf IMPORTMVS_RTP "      <uploaderPort>7777</uploaderPort>\n";
printf IMPORTMVS_RTP "      <targetName>$TDPNAME</targetName>\n";
printf IMPORTMVS_RTP "      <targetPath>$TARGETPATH</targetPath>\n";
printf IMPORTMVS_RTP "      <targetFullPath>$TARGETDIR</targetFullPath>\n";
printf IMPORTMVS_RTP "      <iniFileName>$INIFILE</iniFileName>\n";
printf IMPORTMVS_RTP "      <sourceLanguage>$TDP_LANGUAGE</sourceLanguage>\n";
printf IMPORTMVS_RTP "      <sourceExt>$SRCEXT</sourceExt>\n";
printf IMPORTMVS_RTP "      <objectExt>$OBJEXT</objectExt>\n";
printf IMPORTMVS_RTP "      <binaryExt>$EXEEXT</binaryExt>\n";
printf IMPORTMVS_RTP "      <ansiMode>true</ansiMode>\n";
printf IMPORTMVS_RTP "      <version></version>\n";
printf IMPORTMVS_RTP "      <target></target>\n";
printf IMPORTMVS_RTP "      <exception>true</exception>\n";
printf IMPORTMVS_RTP "      <definitionFile></definitionFile>\n";
printf IMPORTMVS_RTP "      <intdir>$INTDIR</intdir>\n";
printf IMPORTMVS_RTP "      <outdir>$OUTDIR</outdir>\n";
printf IMPORTMVS_RTP "      <ge_incdir>$INCLUDE_DIR_LIST</ge_incdir>\n";
printf IMPORTMVS_RTP "      <ge_alk_file_name></ge_alk_file_name>\n";
printf IMPORTMVS_RTP "      <testProgram>&lt;default&gt;</testProgram>\n";
printf IMPORTMVS_RTP "      <arguments></arguments>\n";
printf IMPORTMVS_RTP "      <javaMainClass></javaMainClass>\n";
printf IMPORTMVS_RTP "      <ge_host_workdir>tmp</ge_host_workdir>\n";
printf IMPORTMVS_RTP "      <javaBuildJarFile>false</javaBuildJarFile>\n";
printf IMPORTMVS_RTP "      <javaJarFileName></javaJarFileName>\n";
printf IMPORTMVS_RTP "      <javaManifest></javaManifest>\n";
printf IMPORTMVS_RTP "      <javaJarOtherDir></javaJarOtherDir>\n";
printf IMPORTMVS_RTP "      <cppFlags>$CPPFLAGS</cppFlags>\n";
printf IMPORTMVS_RTP "      <cflags>$CFLAGS</cflags>\n";
printf IMPORTMVS_RTP "      <tcflags>$TCFLAGS</tcflags>\n";
printf IMPORTMVS_RTP "      <ldflags>$LDFLAGS</ldflags>\n";
printf IMPORTMVS_RTP "      <additionnalObjects>$LIBRARIES</additionnalObjects>\n";
printf IMPORTMVS_RTP "      <debug>false</debug>\n";
printf IMPORTMVS_RTP "      <ge_libdir>$LIBRARY_DIR_LIST</ge_libdir>\n";
printf IMPORTMVS_RTP "      <javaBootClasspath>$JAVA_BOOTCLASSPATH</javaBootClasspath>\n";
printf IMPORTMVS_RTP "      <javaClasspath></javaClasspath>\n";
printf IMPORTMVS_RTP "      <multiThreaded>false</multiThreaded>\n";
printf IMPORTMVS_RTP "      <bufferSize>1024</bufferSize>\n";
printf IMPORTMVS_RTP "      <maxThreads>64</maxThreads>\n";
printf IMPORTMVS_RTP "      <atc_rungcatexit>true</atc_rungcatexit>\n";
printf IMPORTMVS_RTP "      <mainProc></mainProc>\n";
printf IMPORTMVS_RTP "      <clockKind>0</clockKind>\n";
printf IMPORTMVS_RTP "      <sourceFile>&lt;default&gt;</sourceFile>\n";
printf IMPORTMVS_RTP "      <otiFile>&lt;default&gt;</otiFile>\n";
printf IMPORTMVS_RTP "      <xrdFile>&lt;default&gt;</xrdFile>\n";
printf IMPORTMVS_RTP "      <nuerror>30</nuerror>\n";
printf IMPORTMVS_RTP "      <nodline>true</nodline>\n";
printf IMPORTMVS_RTP "      <atobreakonerror>false</atobreakonerror>\n";
printf IMPORTMVS_RTP "      <atonopassdump>false</atonopassdump>\n";
printf IMPORTMVS_RTP "      <atomaxinstances>64</atomaxinstances>\n";
printf IMPORTMVS_RTP "      <printbuffer>false</printbuffer>\n";
printf IMPORTMVS_RTP "      <printbuffersize>1024</printbuffersize>\n";
printf IMPORTMVS_RTP "      <atkbreakonerror>false</atkbreakonerror>\n";
printf IMPORTMVS_RTP "      <atknopassdump>false</atknopassdump>\n";
printf IMPORTMVS_RTP "      <atkreflexivestate>true</atkreflexivestate>\n";
printf IMPORTMVS_RTP "      <atkconstmethods>false</atkconstmethods>\n";
printf IMPORTMVS_RTP "      <atkreentrant>true</atkreentrant>\n";
printf IMPORTMVS_RTP "      <atkstrictcheck>false</atkstrictcheck>\n";
printf IMPORTMVS_RTP "      <st_interface_files></st_interface_files>\n";
printf IMPORTMVS_RTP "      <st_allocation></st_allocation>\n";
printf IMPORTMVS_RTP "      <st_notShared>false</st_notShared>\n";
printf IMPORTMVS_RTP "      <st_thread>false</st_thread>\n";
printf IMPORTMVS_RTP "      <st_thread_function></st_thread_function>\n";
printf IMPORTMVS_RTP "      <st_trace_circular>false</st_trace_circular>\n";
printf IMPORTMVS_RTP "      <st_trace></st_trace>\n";
printf IMPORTMVS_RTP "      <st_bufsize>10</st_bufsize>\n";
printf IMPORTMVS_RTP "      <st_values></st_values>\n";
printf IMPORTMVS_RTP "      <st_time>false</st_time>\n";
printf IMPORTMVS_RTP "      <st_dynfol>false</st_dynfol>\n";
printf IMPORTMVS_RTP "      <st_item_buf>false</st_item_buf>\n";
printf IMPORTMVS_RTP "      <st_item_buf_size>8192</st_item_buf_size>\n";
printf IMPORTMVS_RTP "      <st_dtrack>false</st_dtrack>\n";
printf IMPORTMVS_RTP "      <st_dtrack_buf_size>4096</st_dtrack_buf_size>\n";
printf IMPORTMVS_RTP "      <st_interrecv_timeout>300</st_interrecv_timeout>\n";
printf IMPORTMVS_RTP "      <st_custom>false</st_custom>\n";
printf IMPORTMVS_RTP "      <st_custom_type>0</st_custom_type>\n";
printf IMPORTMVS_RTP "      <fdc_name_opt>0</fdc_name_opt>\n";
printf IMPORTMVS_RTP "      <fdc_value></fdc_value>\n";
printf IMPORTMVS_RTP "      <tsf_name_opt>0</tsf_name_opt>\n";
printf IMPORTMVS_RTP "      <tsf_value></tsf_value>\n";
printf IMPORTMVS_RTP "      <tsf_selective_file></tsf_selective_file>\n";
printf IMPORTMVS_RTP "      <tsf_selective_class></tsf_selective_class>\n";
printf IMPORTMVS_RTP "      <exclude_dir></exclude_dir>\n";
printf IMPORTMVS_RTP "      <dump_incoming_list></dump_incoming_list>\n";
printf IMPORTMVS_RTP "      <dump_returning_list></dump_returning_list>\n";
printf IMPORTMVS_RTP "      <dump_calling_list></dump_calling_list>\n";
printf IMPORTMVS_RTP "      <no_header_instr>true</no_header_instr>\n";
printf IMPORTMVS_RTP "      <instantiate_template>false</instantiate_template>\n";
printf IMPORTMVS_RTP "      <misc_options></misc_options>\n";
printf IMPORTMVS_RTP "      <atc_instr_functions>1</atc_instr_functions>\n";
printf IMPORTMVS_RTP "      <atc_instr_calls>1</atc_instr_calls>\n";
printf IMPORTMVS_RTP "      <atc_instr_blocks>2</atc_instr_blocks>\n";
printf IMPORTMVS_RTP "      <atc_instr_conditions>3</atc_instr_conditions>\n";
printf IMPORTMVS_RTP "      <atc_tio_name>&lt;default&gt;</atc_tio_name>\n";
printf IMPORTMVS_RTP "      <atc_selective_no_ternary>true</atc_selective_no_ternary>\n";
printf IMPORTMVS_RTP "      <atc_selective_no_inline>true</atc_selective_no_inline>\n";
printf IMPORTMVS_RTP "      <atc_selective_no_included>true</atc_selective_no_included>\n";
printf IMPORTMVS_RTP "      <atc_selective_functions_list></atc_selective_functions_list>\n";
printf IMPORTMVS_RTP "      <atc_selective_spec>false</atc_selective_spec>\n";
printf IMPORTMVS_RTP "      <atc_information>0</atc_information>\n";
printf IMPORTMVS_RTP "      <atc_instr_ctrl_prefixe></atc_instr_ctrl_prefixe>\n";
printf IMPORTMVS_RTP "      <atc_instr_ctrl_suffixe>0</atc_instr_ctrl_suffixe>\n";
printf IMPORTMVS_RTP "      <atc_no_metrics>true</atc_no_metrics>\n";
printf IMPORTMVS_RTP "      <atc_user_comment></atc_user_comment>\n";
printf IMPORTMVS_RTP "      <atc_dump_driver>false</atc_dump_driver>\n";
printf IMPORTMVS_RTP "      <att_tdf_name>&lt;default&gt;</att_tdf_name>\n";
printf IMPORTMVS_RTP "      <att_calling_sequenced>false</att_calling_sequenced>\n";
printf IMPORTMVS_RTP "      <att_aggregate_traces>true</att_aggregate_traces>\n";
printf IMPORTMVS_RTP "      <att_template_notes>true</att_template_notes>\n";
printf IMPORTMVS_RTP "      <att_split>true</att_split>\n";
printf IMPORTMVS_RTP "      <att_split_size>5000</att_split_size>\n";
printf IMPORTMVS_RTP "      <att_split_prefixe>&lt;default&gt;</att_split_prefixe>\n";
printf IMPORTMVS_RTP "      <att_loop>false</att_loop>\n";
printf IMPORTMVS_RTP "      <att_loop_options></att_loop_options>\n";
printf IMPORTMVS_RTP "      <att_record_max_stack>true</att_record_max_stack>\n";
printf IMPORTMVS_RTP "      <att_on_fly>false</att_on_fly>\n";
printf IMPORTMVS_RTP "      <att_item_buffer>false</att_item_buffer>\n";
printf IMPORTMVS_RTP "      <att_item_buffer_size>64</att_item_buffer_size>\n";
printf IMPORTMVS_RTP "      <att_partial_dump>false</att_partial_dump>\n";
printf IMPORTMVS_RTP "      <att_signal_action>0</att_signal_action>\n";
printf IMPORTMVS_RTP "      <att_time_stamp>true</att_time_stamp>\n";
printf IMPORTMVS_RTP "      <att_heap_size>true</att_heap_size>\n";
printf IMPORTMVS_RTP "      <att_thread_info>true</att_thread_info>\n";
printf IMPORTMVS_RTP "      <atp_tpf_name>&lt;default&gt;</atp_tpf_name>\n";
printf IMPORTMVS_RTP "      <atp_instr_ctrl></atp_instr_ctrl>\n";
printf IMPORTMVS_RTP "      <atp_errors_fiu>true</atp_errors_fiu>\n";
printf IMPORTMVS_RTP "      <atp_errors_miu>false</atp_errors_miu>\n";
printf IMPORTMVS_RTP "      <atp_errors_sig>true</atp_errors_sig>\n";
printf IMPORTMVS_RTP "      <atp_fmwl>true</atp_fmwl>\n";
printf IMPORTMVS_RTP "      <atp_fmwl_queue_len>100</atp_fmwl_queue_len>\n";
printf IMPORTMVS_RTP "      <atp_fmwl_queue_size>1024</atp_fmwl_queue_size>\n";
printf IMPORTMVS_RTP "      <atp_abwl>true</atp_abwl>\n";
printf IMPORTMVS_RTP "      <atp_abwl_zone_size>16</atp_abwl_zone_size>\n";
printf IMPORTMVS_RTP "      <atp_call_stack>6</atp_call_stack>\n";
printf IMPORTMVS_RTP "      <javaObjectHashSize>1</javaObjectHashSize>\n";
printf IMPORTMVS_RTP "      <javaClassHashSize>1</javaClassHashSize>\n";
printf IMPORTMVS_RTP "      <javaTrigger>METHOD</javaTrigger>\n";
printf IMPORTMVS_RTP "      <javaHitKey>true</javaHitKey>\n";
printf IMPORTMVS_RTP "      <javaNextGC>true</javaNextGC>\n";
printf IMPORTMVS_RTP "      <javaStudioIPAdress>localhost</javaStudioIPAdress>\n";
printf IMPORTMVS_RTP "      <javaStudioPortNb></javaStudioPortNb>\n";
printf IMPORTMVS_RTP "      <javaTpfFileName></javaTpfFileName>\n";
printf IMPORTMVS_RTP "      <javaTsfFileName></javaTsfFileName>\n";
printf IMPORTMVS_RTP "      <javaAnalyze></javaAnalyze>\n";
printf IMPORTMVS_RTP "      <javaAnalyzeAlloc></javaAnalyzeAlloc>\n";
printf IMPORTMVS_RTP "      <javaFilterOption>WITH</javaFilterOption>\n";
printf IMPORTMVS_RTP "      <atq_tqf_name>&lt;default&gt;</atq_tqf_name>\n";
printf IMPORTMVS_RTP "      <atq_dump_driver>false</atq_dump_driver>\n";
printf IMPORTMVS_RTP "      <attolClassName></attolClassName>\n";
printf IMPORTMVS_RTP "      <intermediateFile>&lt;default&gt;</intermediateFile>\n";
printf IMPORTMVS_RTP "      <simulation>false</simulation>\n";
printf IMPORTMVS_RTP "      <preproerrorlevel>true</preproerrorlevel>\n";
printf IMPORTMVS_RTP "      <breakontest>false</breakontest>\n";
printf IMPORTMVS_RTP "      <preparationOptions></preparationOptions>\n";
printf IMPORTMVS_RTP "      <moreoptions>false</moreoptions>\n";
printf IMPORTMVS_RTP "      <filter>0</filter>\n";
printf IMPORTMVS_RTP "      <strategy>0</strategy>\n";
printf IMPORTMVS_RTP "      <reportOutlay>0</reportOutlay>\n";
printf IMPORTMVS_RTP "      <moreRoptions>false</moreRoptions>\n";
printf IMPORTMVS_RTP "      <reportoptions></reportoptions>\n";
printf IMPORTMVS_RTP "      <noComparaison>true</noComparaison>\n";
printf IMPORTMVS_RTP "      <instrumentedComparaison>false</instrumentedComparaison>\n";
printf IMPORTMVS_RTP "      <secondContext>false</secondContext>\n";
printf IMPORTMVS_RTP "      <secondTarget>true</secondTarget>\n";
printf IMPORTMVS_RTP "      <secondIntermediateFile>false</secondIntermediateFile>\n";
printf IMPORTMVS_RTP "      <strictComparaison>false</strictComparaison>\n";
printf IMPORTMVS_RTP "      <comparaison>false</comparaison>\n";
printf IMPORTMVS_RTP "      <userCommandLine></userCommandLine>\n";

printf IMPORTMVS_RTP "    </configuration>\n";
printf IMPORTMVS_RTP "    <javaStub>true</javaStub>\n";
printf IMPORTMVS_RTP "    <javaDisplay>false</javaDisplay>\n";
printf IMPORTMVS_RTP "    <javaReport></javaReport>\n";
printf IMPORTMVS_RTP "    <j2meRestriction>$J2ME_RESTRICTION</j2meRestriction>\n";
printf IMPORTMVS_RTP "  </root_configuration_list>\n";
printf IMPORTMVS_RTP "  <version_file>1</version_file>\n";
printf IMPORTMVS_RTP "</project>\n";
###############################################################################
#  Fin d'ecriture du fichier RTP
###############################################################################


printf IMPORTMVS_INF "    </folder_child>\n";
printf IMPORTMVS_INF "  </folder>\n";
printf IMPORTMVS_INF "  <version_file>1</version_file>\n";
printf IMPORTMVS_INF "</objects>\n";
###############################################################################
#  Fin d'ecriture du fichier INF
###############################################################################


close( IMPORTMVS_RTP );
close( IMPORTMVS_INF );
close( MAKFILE );

#print &PerlTranslate("ImportMakefile.pl", "\nDone.\n");
0;








