#################################################################################
#
#  Licensed Materials - Property of IBM
#  Restricted Material of IBM
#  IBM Rational Test RealTime
#  (c) Copyright IBM Corp. 2003-2006 All Rights Reserved.
#
#  US Governement Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#################################################################################

##########################################################################
#                                                                        # #
# Rational Test RealTime                                                 #   #
#                                                                        #######
#                       -*-  Object Testing node -*-                           #
#                                                                              #
#                                                                              #
# Required global variables:                                                   #
#   @OBJECTS     : object files                                                #
#   $LDFLAGS     : link flags                                                  #
#   $LIBRARIES   : libraries list for linking                                  #
#   $TESTPROGRAM : executable name                                             #
#   $ARGUMENTS   : executable arguments                                        #
#   $EXECMODE    : execution mode ("NORMAL" or "DEBUG")                        #
#   $TDFFILE     : generated TDF file                                          #
#   $AMLFILE     : generated AML report                                        #
#   @OTSFILES    : list of OTS files                                           #
#   $BINDIR      : ATTOL binaries directory                                    #
#   $SCRIPTDIR   : Studio scripts directory                                    #
#   $TARGETDIR   : target package directory                                    #
#   $LOGFILENAME : generated files log                                         #
################################################################################

# To do output in chronological order when stderr and stdout are both used
use FileHandle;
STDOUT->autoflush(1);

# Configuration file
require $ARGV[0];

# Miscellaneous functions 
require $SCRIPTDIR . "Fcts.pl";
require $SCRIPTDIR . "Tools.pl";
require $SCRIPTDIR . "Split.pl";

# Target package related functions
require $SCRIPTDIR . "Products.pl";

# Target-dependant functions
require $TARGETDIR . "/cmd/atl_link.pl";
require $TARGETDIR . "/cmd/atl_exec.pl";
#require $SCRIPTDIR . "codeChecker.pl" if($MISRA_MODE);

################################################################################
# Attol ObjecTest postprocessor execution
# Arguments:
#    $tdf    : traces file
#    $ots    : static correspondence files (space-separated list)
#    $xrd    : generated AML report
# Return value: atopostpro return value
# Required global variables:
#    $BINDIR
# Used global variables:
################################################################################
sub ato_postpro ($$$)
{
   my ($tdf,$ots,$xrd) = @_;

   # command
   my $Command = "$BINDIR" . "$PATH_SEPARATOR" . "atopospro -ots $ots -tdf \"$tdf\" -xrd \"$xrd\"";

   # execution
   my $Status = SystemP ($Command);
   return $Status;
}

################################################################################
# Here is the beginning
################################################################################
&CheckIntDir;
&EnterInScript;

ClearLogFile($LOGFILENAME);

my $status = 0;

$OUTFILE = "$ATL_OUT_FILE";

($tdfdir, $tdfname, $tdfext) = SplitFileName ($OUTFILE);

#  codeChecker_link() if($MISRA_MODE);
#----------------------------------------------------------------------------
## Linkage
#----------------------------------------------------------------------------
if ($STAGE =~ /l/) 
{
  #----------------------------------------------------------------------------
  if ( $ATL_RUNTIME_FORMAT ne "NONE") {
    ## do not forget object file of target package.
    if (&MakeTargetPackageObject) {
      exit 1;
    }
    if($ATL_RUNTIME_FORMAT eq "OBJ") {
       push( @OBJECTS, &GetTargetPackageLib($OBJEXT) );
    } else {
       push( @ADDITIONAL_LIBRARIES, &GetTargetPackageLib($LIBEXT) );
    }
  }
      
  print &PerlTranslate("ObjecTest.pl", "Linking %1...\n", "%1 is the program to be linked", $TESTPROGRAM);
  $status = atl_link ($TESTPROGRAM, \@OBJECTS, $LDFLAGS,
                      \@LIBRARY_DIR_LIST, $LIBRARIES, \@ADDITIONAL_LIBRARIES);
  if ($status != 0 ) { die &PerlTranslate("ObjecTest.pl", "Failed.\n"); }
  
  ## Do not forget the OBJ file in output log
  open ( LOG, ">>$LOGFILENAME" ) or die &PerlTranslate("ObjecTest.pl", "Cannot open log file: %1\n", "%1 is the reason given by the Operating System", $!);
  print  LOG "EXE $TESTPROGRAM\n";
  close( LOG );
}

#----------------------------------------------------------------------------
## Execution
#----------------------------------------------------------------------------
if ($STAGE =~ /e/ )
{
  print &PerlTranslate("ObjecTest.pl", "Executing %1 %2...\n", "%1 is the program to be executed and %2 contains the arguments given to it", $TESTPROGRAM, $ARGUMENTS);
  $status = AtlExec ($TESTPROGRAM, $OUTFILE, $ARGUMENTS);
  if ($status != 0 )
  {
    print &PerlTranslate("ObjecTest.pl", "Executable terminated with error code %1.\n", "%1 is the error code number", $status);
  }

    if (( ! -f $OUTFILE) && ( ! $SOCKET_UPLOAD ))
    {
      print &PerlTranslate("ObjecTest.pl", "No trace generated.\n");
      exit(1);
    }

    SplitTraces ($OUTFILE);

    if ( ! $used[$tdf] )
    {
      print &PerlTranslate("ObjecTest.pl", "No TDF instruction found.\n");
      exit(1);
    }
}

#----------------------------------------------------------------------------
## Postprocessing
#----------------------------------------------------------------------------
if ($STAGE =~ /r/ )
{
  # GD: wait for end of execution before running atopospro - tempo (cf DR 2021)
  my $wait_time = 2;
  if ($SOCKET_UPLOAD)
    {
      sleep(5 * $wait_time);
    }
  if (($ATTMODE && $ATT_ON_THE_FLY) || ($SOCKET_UPLOAD))
    {
      # Initialization
      my $count_lines="0";
      my $start_count_line="0";
      my $start_time = time();
      my $current_time = time();
      my $end="0";
      
      # While the file grows do nothing.
      # when the file does not grow anymore, run the atopospro
      while ($end != "1") {
	  if (open(INPUTFL, $TDFFILE))
	  {
	      $count_lines="0";
	      while(<INPUTFL>)
		{
		  $count_lines++;
		}

	      $current_time = time();

	      #if has grown.
	      if (($count_lines - $start_count_line) > 0)
		{
		  $start_count_line = $count_lines;
		  $count_lines="0";
		  $start_time = $current_time;
		} else {
		  #same file.
		  if (($current_time - $start_time) > $wait_time)
		    {
		      $end="1";
		    }
		}
		if ($end != 1)
		{
		  sleep($wait_time);
		}
	  } else {
	      #secure if there is no TDF file.
	      sleep($wait_time);
	      if (open(INPUTFL, $TDFFILE))
	      {
	      } else {
		  $current_time = time();
		  if ($current_time - $start_time > $wait_time)
		  {
		      $end="1";
		  }
	      }
	  }
      }
    }
  print &PerlTranslate("ObjecTest.pl", "Test Report Generation...\n");

  $otslist = "";
  foreach $ots ( @OTSFILES )
  {
     $otslist .= "\"$ots\" ";
  }
  $status = ato_postpro ($TDFFILE, $otslist, $XRDFILE);
  if ($status != 0 ) { print &PerlTranslate("ObjecTest.pl", "Failed.\n"); exit(1); }
  open ( LOG, ">>$LOGFILENAME" ) or die &PerlTranslate("ObjecTest.pl", "Cannot open log file: %1\n", "%1 is the reason given by the Operating System", $!);
  print  LOG "XRD $XRDFILE\n";
  close( LOG );
}

## Intermediate files remove
# none

#print &PerlTranslate("ObjecTest.pl", "Done.\n");

0;
#
################################################################################
