##############################################################################
#
#  Licensed Materials - Property of IBM
#  Restricted Material of IBM
#  IBM Rational Test RealTime
#  (c) Copyright IBM Corp. 2003-2006 All Rights Reserved.
#
#  US Governement Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
##############################################################################
#
# Author: Simon Washbrook
#
# Development notes:
# Option -html not implemented as it does not work
#
##############################################################################


use strict;
use TestRTUtil;
BEGIN {
  if ($^O eq "MSWin32") {
   use File::DosGlob 'glob';
 }
}

##############################################################################
# Help

sub help {
  my ($d,$n,$e) = TestRTUtil::SplitFileName($0);
  print "$n : Creates a temporary project with the test result files passed asparameter.\nThese results can then be exported to HTML\n";
  print "Command line:\n";
  print "\t$n [-help] [-html] [-keep] [<report files>]\n";
  print "Options:\n";
  print "\t-help Displays this help message\n";
  print "\t-html <dir> create the directory for HTML exports\n";
  print "\t-keep Keeps the temporary project that was generated\n";
  print "\tlist of space seperated file names. Only test result files are accepted.\n";
  print "Test result files must have the following extensions\n";
  print "\t.spt        global result file generated by the execution\n";
  print "\t.xrd        Component Testing report file\n";
  print "\t.crc        Rule Checker report file\n";
  print "\t.met        Static Metric report file\n";
  print "\t.fdc, .tio  Code Coverage report files\n";
  print "\t.tsf, .tpf  Memory Profiling report files\n";
  print "\t.tsf, .tqf  Performance profiling report files\n";
  print "\t.tsf, .tdf  Runtime Tracing report file\n";
  print "\t.log, .xtp  file providing the listing of files\n";
  print "Files must have absolute paths or be relative to the current directory.\n";
  print "\n\n(c) Copyright 2005-2006 IBM Corp. All right reserved\n";
}
###########################################################################
# end called at the end of the instrumentation (link time)
sub reports
{
  my $log=shift;
  
	my $otsfiles;
	my $staticfiles;
	open LOG, "<$log";
	while(<LOG>)
	{
		chomp;
		if(/^OTS (.+)$/){
		  $otsfiles.=$1.' ';
		}elsif (/^DUM (.+)$/){
		  my $f=$1;
	  	  unlink($f);
		}elsif (/^XOB/){
			#file is ignored
		}elsif (/^[A-Z]{3} (.+)$/){
		  my $f=$1;
		  my @l=grep(/^\Q$f\E$/, @ARGV);
		  unshift(@ARGV,$f) unless(scalar(@l));
		}else{
		  unshift(@ARGV,$_) unless(/^[#;]/); # this is not a log generated by us
		}
	}
	close(LOG);
	if($otsfiles){
		my $command="atopospro -ots $otsfiles -tdf atltrace.tdf -xrd contract.xrd";
		print "Running the command \n$command\n" ;
		system ($command);
		push(@ARGV,"contract.xrd");
	}
}

##############################################################################
# Parse parameters to extract report file types

sub parseArgs {
  unless (@ARGV) {
    	print "\nERROR: No arguments\n";
    	help();
    	exit 1;
  }

  my %args;
  my (@xrd,@crc,@met,@fdc,@tio,@tsf,@tpf,@tqf,@tdf, @studio_args);
  my $spt; #only 1 spt file can be on the command line the last on is the one
  while (@ARGV) {
    $_ = shift @ARGV;
    s/\"//g;
    print "arg: $_\n" if ($args{verbose});
    if (/\*/) {
      print "\nExpanding argument:\n$_\n" if ($args{verbose});
      #unshift(@studio_args, "\"".$_."\"");
      $_ =~ s,\\,/,g;
      $_ =~ s/(\s)/\\$1/g;
      my @files = glob $_;
      foreach (@files) {
	print "\t$_\n" if ($args{verbose});
	if (/\.xrd$/i) {
	  push (@xrd, $_);
	} elsif (/\.crc$/i) {
	  push (@crc, $_);
	} elsif (/\.met$/i) {
	  push (@met, $_);
	} elsif (/\.fdc$/i) {
	  push (@fdc, $_);
	} elsif (/\.tio$/i) {
	  push (@tio, $_);
	} elsif (/\.tsf$/i) {
	  push (@tsf, $_);
	} elsif (/\.tpf$/i) {
	  push (@tpf, $_);
	} elsif (/\.tqf$/i) {
	  push (@tqf, $_);
	} elsif (/\.tdf$/i) {
	  push (@tdf, $_);
	} else {
	  print "\nERROR: unknown file \"$_\"\n";
	  help();
	  exit (1);
	}
      }
      print "\n" if ($args{verbose});

    } elsif (/^-help$/) {
      help();
      exit 0;
     } elsif (/^-html$/) {
       $args{html} = shift @ARGV;
       unless (-d $args{html}) {
	mkdir ($args{html},0777) || die "Can not create the html output directory \"".$args{html}."\"\n";
	unshift(@studio_args, "-html $args{html}");    	
       }
    } elsif (/^-keep$/) {
      $args{keep} = 1;
    } elsif (/^-debug$/) {
      $args{verbose} = 1;
    } elsif (/^-r$/) {
      unshift(@studio_args, "-r");    	
    } elsif (/^-/) {
      print "\nERROR: unknown option \"$_\"\n";
      help();
      exit 1;
    } elsif (/\.xrd$/i) {
      push (@xrd, $_);
    } elsif (/\.crc$/i) {
      push (@crc, $_);
    } elsif (/\.met$/i) {
      push (@met, $_);
    } elsif (/\.fdc$/i) {
      push (@fdc, $_);
    } elsif (/\.tio$/i) {
      push (@tio, $_);
    } elsif (/\.tsf$/i) {
      push (@tsf, $_);
    } elsif (/\.tpf$/i) {
      push (@tpf, $_);
    } elsif (/\.tqf$/i) {
      push (@tqf, $_);
    } elsif (/\.tdf$/i) {
      push (@tdf, $_);
    } elsif (/\.spt$/i) {
      $spt= $_;
    } elsif ((/\.log$/i) || (/\.xtp$/i)) {
      reports ($_);
    } else {
      print "\nERROR: unknown file \"$_\"\n";
      help();
      exit (1);
    }
  }
  @xrd=sort @xrd;
  @crc=sort @crc;
  @met=sort @met;
  @fdc=sort @fdc;
  @tsf=sort @tsf;
  $args{XRD} = join(',', @xrd);
  $args{CRC} = join(',', @crc);
  $args{MET} = join(',', @met);
  $args{FDC} = join(',', @fdc);
  $args{TIO} = join(',', @tio);
  $args{TSF} = join(',', @tsf);
  $args{TPF} = join(',', @tpf);
  $args{TQF} = join(',', @tqf);
  $args{TDF} = join(',', @tdf);
  $args{SPT} = $spt;
  $args{STUDIO} = join(' ',@studio_args).' "'.join('" "', @xrd, @crc, @met, @fdc, @tio, @tsf, @tpf, @tqf, @tdf ).'"';
  return %args;
}


##############################################################################
# Generate project

sub generateProject {
  my $projectName = shift;
  my %args = @_;
  my %typeCode=('CRC','2138245498_CRC','XRD','2138245498_XRD','FDC','2138245498_FDC','TIO','2138245498_TIO','TSF','2138245498_TSF' ,'TPF','2138245498_TPF' ,'TQF','2138245498_TQF' ,'TDF','2138245498_TDF','MET','2138245498_MET');
#  my %typeCode=('CRC','2138245498_1242109961','XRD','2138245498_1242437650','FDC','2138245498_1242107404','TIO','2138245498_1241842462','TSF','2138245498_1242306846' ,'TPF','2138245498_1242307102' ,'TQF','2138245498_1242307358' ,'TDF','2138245498_1242304030','MET','2138245498_1243483911');
#  my %typeCode=('CRC', ,'XRD','150676_384','FDC','150676_467','TIO','150676_397','TSF','150676_432' ,'TPF','150676_438' ,'TQF','150676_436' ,'TDF','150676_414');

  open (PRJ, ">${projectName}.rtp") || die "Cannot open the project \"${projectName}.rtp\"\n";
  print PRJ <<"END";
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE project SYSTEM "C:\Program files\Rational\TestRealTime\lib\project.dtd" >
<project>
  <group>
    <node>
      <data>
        <name>$projectName</name>
        <renameable>false</renameable>
        <deletable>false</deletable>
        <open>true</open>
        <sorted>false</sorted>
      </data>
      <current_configuration>C Visual 6.0</current_configuration>
      <state>0</state>
      <background>false</background>
      <configuration_list>
        <configuration>
          <name>C Visual 6.0</name>
        </configuration>
      </configuration_list>
    </node>
    <group_child>
      <unit_testing>
        <test>
          <node>
            <data>
              <name>temp</name>
              <renameable>true</renameable>
              <deletable>true</deletable>
              <open>true</open>
              <sorted>false</sorted>
            </data>
            <current_configuration>C Visual 6.0</current_configuration>
            <state>0</state>
            <background>false</background>
            <outfilename_list>
END
  foreach my $type (qw(XRD CRC FDC TIO TSF TPF TQF TDF MET)) {
    print PRJ <<"END";
              <outfilename>
                <filetype>$typeCode{$type}</filetype>
                <filepath>$args{$type}</filepath>
              </outfilename>
END
}
  print PRJ <<"END";
            </outfilename_list>
            <perlscript_after_child>UnitTesting.pl</perlscript_after_child>
            <configuration_list>
              <configuration>
                <name>C Visual 6.0</name>
              </configuration>
            </configuration_list>
          </node>
        </test>
      </unit_testing>
    </group_child>
  </group>
  <object_file>${projectName}.inf</object_file>
  <sort_method>0</sort_method>
  <root_configuration_list>
    <configuration>
      <name>C Visual 6.0</name>
      <targetName>C Visual 6.0</targetName>
      <executionFlag>24127</executionFlag>
    </configuration>
  </root_configuration_list>
  <version_file>1</version_file>
</project>
END

  close (PRJ);

  # Generate .inf file
  open (INF, ">${projectName}.inf") || die "Cannot open the project \"${projectName}.inf\"\n";
  print INF <<"END";
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE objects SYSTEM "C:\Program files\Rational\TestRealTime\lib\project.dtd" >
<objects>
  <version_file>1</version_file>
</objects>

END
  close (INF);

}

##############################################################################
# Run studio with the project.

sub runStudio {
  my $projectName = shift;
  my %args = @_;

  my $command = "studio ". $args{STUDIO};
    $command .= " ${projectName}.rtp ";
    if($args{SPT}){
    	$command .= $args{SPT};
        if($args{FDC}) {
        	$command .= " attolcov.tio"   unless($args{TIO});
        }
        if($args{TSF}) {
		$command .= " atltrace.tdf"   unless ($args{TDF});
		$command .= " purifylt.tpf"   unless ($args{TPF});
		$command .= " quantifylt.tqf" unless ($args{TQF});
	}
    }
  print "Running the command \n$command\n" if ($args{verbose});
  system ($command);
}


##############################################################################
# remove temporary project
sub removeProject {
  my $projectName = shift;
  my %args = @_;

  unless ($args{keep}) {
    unlink ("${projectName}.rtp");
    unlink ("${projectName}.inf");
  }
}

##############################################################################
# Main program
sub main {
  my %args = parseArgs();
  generateProject("temp", %args);
  runStudio("temp", %args);
  removeProject("temp", %args);
}

###########################################################################

main();
1;

